@@ -1,14 +1,20 @@
-use crate::{channel_status::ChannelStatus, internal_rpc::InternalRPCHandle, protocol};
+use crate::{
+    channel_status::ChannelStatus, internal_rpc::InternalRPCHandle, protocol, types::ChannelId,
+};
 use std::fmt;
 
 pub(crate) struct ChannelCloser {
-    id: u16,
+    id: ChannelId,
     status: ChannelStatus,
     internal_rpc: InternalRPCHandle,
 }
 
 impl ChannelCloser {
-    pub(crate) fn new(id: u16, status: ChannelStatus, internal_rpc: InternalRPCHandle) -> Self {
+    pub(crate) fn new(
+        id: ChannelId,
+        status: ChannelStatus,
+        internal_rpc: InternalRPCHandle,
+    ) -> Self {
         Self {
             id,
             status,
@@ -31,7 +37,7 @@ impl Drop for ChannelCloser {
         if self.status.auto_close(self.id) {
             self.internal_rpc.close_channel(
                 self.id,
-                protocol::constants::REPLY_SUCCESS as u16,
+                protocol::constants::REPLY_SUCCESS,
                 "OK".to_string(),
             );
         }
